@@ -1,7 +1,7 @@
 extensions = ['sphinxcontrib.bibtex']
 exclude_patterns = ['_build']
 latex_documents = [
-    ('contents', 'test.tex',
+    ('index', 'test.tex',
      u'Test',
      u'Mr. Test', 'manual'),
 ]
