@@ -19,6 +19,6 @@ def teardown_module():
 @with_app(srcdir=srcdir, warningiserror=True)
 def test_issue77(app, status, warning):
     app.builder.build_all()
-    output = (app.outdir / "contents.html").read_text(encoding='utf-8')
-    assert len(re.findall('\\[APAa\\]', output)) == 2
-    assert len(re.findall('\\[APAb\\]', output)) == 2
+    output = (path(app.outdir) / "index.html").read_text(encoding='utf-8')
+    assert len(re.findall('\\[APAa\\]', output)) == 1
+    assert len(re.findall('\\[APAb\\]', output)) == 1
