@@ -20,9 +20,9 @@ def teardown_module():
 @with_app(srcdir=srcdir, warningiserror=True)
 def test_list_bullet(app, status, warning):
     app.builder.build_all()
-    output = (app.outdir / "contents.html").read_text()
+    output = (path(app.outdir) / "index.html").read_text()
     assert re.search(
-        '<ul .* id="bibtex-bibliography-contents-0">'
+        '<ul .* id="bibtex-bibliography-index-0">'
         '.*<li>.*Akkerdju.*</li>'
         '.*<li>.*Bro.*</li>'
         '.*<li>.*Chap.*</li>'
