@@ -17,15 +17,21 @@ def teardown_module():
     (srcdir / '_build').rmtree(True)
 
 
+def htmlbibitem(label, text):
+    return (
+        '.*<dt class="bibtex label".*><span class="brackets">'
+        '<a.*>{0}</a></span></dt>\\s*<dd>.*{1}.*</dd>'.format(label, text))
+
+
 @with_app(srcdir=srcdir, warningiserror=True)
 def test_list_citation(app, status, warning):
     app.builder.build_all()
-    output = (app.outdir / "contents.html").read_text()
+    output = (path(app.outdir) / "index.html").read_text()
     assert re.search(
-        '<p id="bibtex-bibliography-contents-0">'
-        '.*<tr><td class="label">.*\\[1\\].*</td><td>.*Akkerdju.*</td></tr>'
-        '.*<tr><td class="label">.*\\[2\\].*</td><td>.*Bro.*</td></tr>'
-        '.*<tr><td class="label">.*\\[3\\].*</td><td>.*Chap.*</td></tr>'
-        '.*<tr><td class="label">.*\\[4\\].*</td><td>.*Dude.*</td></tr>'
-        '.*</p>',
+        '<p id="bibtex-bibliography-index-0">'
+        + htmlbibitem("1", "Akkerdju")
+        + htmlbibitem("2", "Bro")
+        + htmlbibitem("3", "Chap")
+        + htmlbibitem("4", "Dude")
+        + '.*</p>',
         output, re.MULTILINE | re.DOTALL)
